# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.models_api import ModelsApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestModelsApi(unittest.TestCase):
    """ModelsApi unit test stubs"""

    def setUp(self):
        self.api = ModelsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_many_base_model_controller_model(self):
        """Test case for create_many_base_model_controller_model

        Create many Model  # noqa: E501
        """
        pass

    def test_create_one_base_model_controller_model(self):
        """Test case for create_one_base_model_controller_model

        Create one Model  # noqa: E501
        """
        pass

    def test_delete_one_base_model_controller_model(self):
        """Test case for delete_one_base_model_controller_model

        Delete one Model  # noqa: E501
        """
        pass

    def test_get_many_base_model_controller_model(self):
        """Test case for get_many_base_model_controller_model

        Retrieve many Model  # noqa: E501
        """
        pass

    def test_get_one_base_model_controller_model(self):
        """Test case for get_one_base_model_controller_model

        Retrieve one Model  # noqa: E501
        """
        pass

    def test_model_controller_clone_model(self):
        """Test case for model_controller_clone_model

        Clone existing model  # noqa: E501
        """
        pass

    def test_model_controller_get_many_and_join_metadata(self):
        """Test case for model_controller_get_many_and_join_metadata

        Retrieve model and metadata  # noqa: E501
        """
        pass

    def test_model_controller_get_model_audit_log(self):
        """Test case for model_controller_get_model_audit_log

        Get model audit log  # noqa: E501
        """
        pass

    def test_model_controller_get_recent_models(self):
        """Test case for model_controller_get_recent_models

        Retrieve recent models  # noqa: E501
        """
        pass

    def test_replace_one_base_model_controller_model(self):
        """Test case for replace_one_base_model_controller_model

        Replace one Model  # noqa: E501
        """
        pass

    def test_update_one_base_model_controller_model(self):
        """Test case for update_one_base_model_controller_model

        Update one Model  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.databases_api import DatabasesApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestDatabasesApi(unittest.TestCase):
    """DatabasesApi unit test stubs"""

    def setUp(self):
        self.api = DatabasesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_database_controller_clean_database(self):
        """Test case for database_controller_clean_database

        Remove temp tables from Databases  # noqa: E501
        """
        pass

    def test_database_controller_sync(self):
        """Test case for database_controller_sync

        Sync Databases  # noqa: E501
        """
        pass

    def test_get_many_base_database_controller_database(self):
        """Test case for get_many_base_database_controller_database

        Retrieve many Database  # noqa: E501
        """
        pass

    def test_get_one_base_database_controller_database(self):
        """Test case for get_one_base_database_controller_database

        Retrieve one Database  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
